@@ -14,8 +14,7 @@ rot.matrix <- function(ksi, theta, rads = FALSE) {
     lat <- ksi[1]
     long <- ksi[2]
     the <- theta
-  }
-  if (rads == FALSE) {
+  } else {
     lat <- ksi[1] * pi/180
     long <- ksi[2] * pi/180
     the <- theta * pi/180
@@ -25,4 +24,4 @@ rot.matrix <- function(ksi, theta, rads = FALSE) {
   t3 <- sin(lat)
   L <- matrix(c(0, t3, -t2, -t3, 0, t1, t2, -t1, 0), ncol = 3)
   diag(3) + L * sin(the) + L %*% L * (1 - cos(the))
-}
+}
\ No newline at end of file
